@@ -1,12 +1,11 @@
 package HTML::FormFu::Model::DBIC;
 
-use strict;
-our $VERSION = '2.01_01'; # TRIAL VERSION
-
 use strict;
 use warnings;
 use base 'HTML::FormFu::Model';
 
+our $VERSION = '2.01'; # VERSION
+
 use HTML::FormFu::Util qw( _merge_hashes );
 use List::MoreUtils qw( none notall );
 use List::Util qw( first );
@@ -1144,7 +1143,7 @@ HTML::FormFu::Model::DBIC - Integrate HTML::FormFu with DBIx::Class
 
 =head1 VERSION
 
-version 2.01_01
+version 2.01
 
 =head1 SYNOPSIS
 
